@@ -6,11 +6,13 @@ use warnings FATAL => 'all';
 use NEXT;
 use Symbol;
 use Tie::IxHash;
-use CGI::Cookie;
+use CGI::Simple::Cookie;
 use Digest::HMAC_MD5;
 use Digest::HMAC_SHA1;
 use Class::Accessor::Fast;
-our $VERSION = 0.05;
+
+our $VERSION = '1.01';
+$VERSION = eval $VERSION; # numify for warning-free dev releases
 
 # apparently this should be done by subclassing Catalyst::Request and using
 # response_class, but I'm suspicious that that process isn't tolerant to
@@ -137,7 +139,7 @@ sub finalize {
     while ( my ( $name, $cookie ) = each %{ $c->response->cookies } ) {
 
         # see finalize_cookies hook, below, for comments
-        my $cgicookie = CGI::Cookie->new(
+        my $cgicookie = CGI::Simple::Cookie->new(
             -name  => $name,
             -value => $cookie->{value},
         );
@@ -177,12 +179,12 @@ sub finalize_cookies {
 
     while ( my ( $name, $cookie ) = each %{ $c->response->cookies } ) {
 
-        # creating a tmp CGI::Cookie is handy for as_string,
+        # creating a tmp CGI::Simple::Cookie is handy for as_string,
         # and also because we can consistenly use ->value as a list
         # 
-        # only -name and -value are used because this is what CGI::Cookie->parse()
+        # only -name and -value are used because this is what CGI::Simple::Cookie->parse()
         # will pass back from an HTTP header - prepare_cookies needs identical hash
-        my $cgicookie = CGI::Cookie->new(
+        my $cgicookie = CGI::Simple::Cookie->new(
             -name  => $name,
             -value => $cookie->{value},
         );
@@ -218,8 +220,7 @@ Catalyst::Plugin::HashedCookies - Tamper-resistant HTTP Cookies
 
 =head1 VERSION
 
-This document refers to version 0.05 of Catalyst::Plugin::HashedCookies,
-released Monday May 2, 2006.
+This document refers to version 1.01 of Catalyst::Plugin::HashedCookies
 
 =head1 SYNOPSIS
 
@@ -390,19 +391,10 @@ All the helpful people in #catalyst.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) The University of Oxford 2006. All Rights Reserved.
+Copyright (c) The University of Oxford 2008.
 
-This program is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published by the
-Free Software Foundation.
-
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
-St, Fifth Floor, Boston, MA 02110-1301 USA
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 =cut
 
